@@ -60,6 +60,30 @@ class Client:
         response = requests.request("POST", url, headers=headers, json=payload)
         print('sendPushNotification',payload,headers, response, url)
 
+    def getPortfolioStocks(self, roomId):
+        url = "{}/getPortfolioStocks".format(self.config['wss']['api'])
+        headers = {'Content-Type': 'application/json', 'Authorization': self.token}
+        payload = {"userId": roomId, "clientId":self.client_id}
+        response = requests.request("POST", url, headers=headers, json=payload)
+        print('getPortfolioStocks',payload,headers, response.text, url)
+        return response
+
+    def getWatchListStocks(self, roomId):
+        url = "{}/getWatchListStocks".format(self.config['wss']['api'])
+        headers = {'Content-Type': 'application/json', 'Authorization': self.token}
+        payload = {"userId": roomId, "clientId":self.client_id}
+        response = requests.request("POST", url, headers=headers, json=payload)
+        print('getWatchListStocks',payload,headers, response.text, url)
+        return response
+
+    def getAlertListStocks(self, roomId):
+        url = "{}/getAlertListStocks".format(self.config['wss']['api'])
+        headers = {'Content-Type': 'application/json', 'Authorization': self.token}
+        payload = {"userId": roomId, "clientId":self.client_id}
+        response = requests.request("POST", url, headers=headers, json=payload)
+        print('getAlertListStocks',payload,headers, response.text, url)
+        return response
+
     def sendEmail(self, userId, subject, html):
         url = "{}/sendEmailFromBot".format(self.config['wss']['messageModuleURL'])
         headers = {'Content-Type': 'application/json', 'Authorization': self.token}
